@@ -1,6 +1,6 @@
 from __future__ import annotations
 from typing import ClassVar, TYPE_CHECKING
-from jsonclasses.orm_object import ORMObject
+from jsonclasses.orm import ORMObject
 if TYPE_CHECKING:
     from .aconf import AConf
 
