@@ -2,7 +2,6 @@ from __future__ import annotations
 from typing import Union, Callable, Optional, overload, cast
 from datetime import timedelta
 from jsonclasses.isjsonclass import isjsonclass
-from .aconf import AConf
 from .api_object import APIObject
 from .auth_conf import AuthConf
 
@@ -36,6 +35,7 @@ def authorized(
                              'JSONClass class.')
         cls = cast(type[APIObject], cls)
         auth_conf = AuthConf(expires_in=expires_in)
+        cls.auth_conf = auth_conf
         API(cls.cdef.jconf.cgraph.name).record_auth(cls, auth_conf)
         return cls
     else:
